<?php

/**
 * @file
 * Provides common batch functions for NamePasswords check.
 */

use Drupal\security_review\CheckResult;
use Drupal\user\Entity\User;

/**
 * Batch operation for NamePassowrds, 100 at a time.
 *
 * @param array $uids
 *   Array of users IDs.
 * @param string $check
 *   Name of the check being run, defaults to View Access.
 * @param array $context
 *   Batch context that stores info.
 */
function security_review_process_users(array $uids, string $check, array &$context): void {
  if (empty($context['sandbox'])) {
    $context['sandbox'] = [];
    $context['sandbox']['progress'] = 0;
    $context['sandbox']['max'] = count($uids);
    $context['results']['findings'] = [];
  }

  $ids = array_slice($uids, $context['sandbox']['progress'], 100);
  $users = User::loadMultiple($ids);
  foreach ($users as $user) {
    $findings = [];
    $user_auth = \Drupal::service('user.auth');

    if (!$user_auth->authenticate($user->getDisplayName(), $user->getPassword())) {
      $findings[] = $user->getDisplayName();
    }

    if (!empty($findings)) {
      $context['results']['findings'] = array_merge($context['results']['findings'], $findings);
    }

    // Update our progress information.
    $context['sandbox']['progress']++;
    $context['message'] = t('Running Batch "@check"',
      ['@check' => $check]
    );
  }

  // Inform the batch engine that we are not finished,
  // and provide an estimation of the completion level we reached.
  if ($context['sandbox']['progress'] != $context['sandbox']['max']) {
    $context['finished'] = $context['sandbox']['progress'] / $context['sandbox']['max'];
  }
}

/**
 * Callback for finishing a bulk check.
 */
function security_review_process_users_finished($success, $results, $operations): void {
  $plugin = \Drupal::service('plugin.manager.security_review.security_check')->createInstance('name_passwords');
  if ($success) {
    $result = CheckResult::SUCCESS;
    if (!empty($results['findings'])) {
      $result = CheckResult::FAIL;
    }
    $plugin->createResult($result, $results['findings']);
  }
}
